package App::realpath;

our $DATE = '2021-07-15'; # DATE
our $VERSION = '0.002'; # VERSION

1;
# ABSTRACT: Print the resolved (absolute) path

__END__

=pod

=encoding UTF-8

=head1 NAME

App::realpath - Print the resolved (absolute) path

=head1 VERSION

This document describes version 0.002 of App::realpath (from Perl distribution App-realpath), released on 2021-07-15.

=head1 DESCRIPTION

See the included script L<realpath> (or its alias (L<abspath>).

=head1 HOMEPAGE

Please visit the project's homepage at L<https://metacpan.org/release/App-realpath>.

=head1 SOURCE

Source repository is at L<https://github.com/perlancar/perl-App-realpath>.

=head1 BUGS

Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=App-realpath>

When submitting a bug or request, please include a test-file or a
patch to an existing test-file that illustrates the bug or desired
feature.

=head1 SEE ALSO

L<App::relpath>

L<App::quickabspath>

=head1 AUTHOR

perlancar <perlancar@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2021, 2019 by perlancar@cpan.org.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
